# www_robot
A WWW Robot library, made for Python.

## Installation
```sh
pip install www_robot
```

## Usage
```python
import www_robot
```

## Contributing
Please feel free to fork and contribute!

## License
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.
